\name{denoise}
\alias{denoise}
\title{Denoising of 3-D Images}
\description{
  Denoise noisy 3-D images
}
\usage{
denoise(z,g,n1,n2,n3,h_star,u,h)
}
\arguments{
  \item{z}{a column vector representing intesities of the pixels of the true image, of type \code{"numeric"}.
           Please note that 3-D matrix is written as a long column. For demonstration please see
           the example provided. If the true image is unknown, then the column vector of intensities of the pixels of observed noisy image will
           work, but out_mse, out_js and out_js_true, obviously will not be usable.}
  \item{g}{a column vector representing intesities of the pixels of noisy image, of type \code{"numeric"}.}
  \item{n1}{a scalar of type \code{"numeric"}. It denotes the number of pixels along x-axis.}
  \item{n2}{a scalar of type \code{"numeric"}. It denotes the number of pixels along y-axis.}
  \item{n3}{a scalar of type \code{"numeric"}. It denotes the number of pixels along z-axis.}
  \item{h_star}{a scalar of type \code{"numeric"}. It is the badwidth parameter for edge detection.}
  \item{u}{a scalar of type \code{"numeric"}. It is the threshold parameter for edge detection.}
  \item{h}{a scalar of type \code{"numeric"}. It is the bandwidth parameter for smoothing.}
}
\value{
 \item{out_mse}{estimated MISE value, valid only if true image is known.}
 \item{out_js}{estimated JS value of the denoised image, valid only if true image is known.}
 \item{out_js_true}{estimated JS value of the true image, valid only if true image is known.}
 \item{output}{column vector representing intesities of the pixels of the denoised image.}
}
\examples{
 n1 <- 64
 n2 <- 64
 n3 <- 64
 z <- rep(0,n1*n2*n3)
 for (i in 1:n1){ for (j in 1:n2){ for (k in 1:n3){
 z[(i-1)*n2*n3+(j-1)*n3+k] <- -(i/n1-0.5)^2 -(j/n2-0.5)^2 -(k/n3-0.5)^2
 if (  ((abs(i/n1-0.5)<=0.25) & (abs(j/n2-0.5)<=0.25) & (abs(k/n3-0.5)<=0.25)) )
 {z[(i-1)*n2*n3+(j-1)*n3+k] <- -(i/n1-0.5)^2 -(j/n2-0.5)^2 -(k/n3-0.5)^2 + 1}
 if ( (((i/n1-0.5)^2+(j/n2-0.5)^2 <=0.15^2) & (abs(k/n3-0.5)<=0.35))  )
 {z[(i-1)*n2*n3+(j-1)*n3+k] <- -(i/n1-0.5)^2 -(j/n2-0.5)^2 -(k/n3-0.5)^2 + 1}
 }}}

 ntemp <- n1*n2*n3
 g <- rep(0,ntemp)
 for (i in 1:ntemp){
 g[i] <- z[i] + rnorm(1,0,0.1)
 }

 result <- denoise(z,g,64,64,64,0.023,13,0.037)
 result$out_mse
 result$out_js
 result$out_js_true
 t <- array(0,dim=c(n1,n2,n3))
 for (i in 1:n1) {for (j in 1:n2){ for (k in 1:n3){
 t[i,j,k] <- result$output[(i-1)*n2*n3+(j-1)*n3+k]}}}
 image(c(1:64),c(1:64),t[32,1:64,1:64],col=gray((0:128)/128))
}
\keyword{misc}
